TaycanService class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
Static Methods
addToRouter ({String routerName = "router" , required String classImport , required String createTemplate (String originalFile ) })
→ dynamic
Adds a new route to the router.
createDirectoriesFromCreationPath (String ? creationPath , String folder )
→ dynamic
Create directories from a creationPath.
createPathForDartFile ({required String folderPath , required String className , String ? prefix , String ? creationPath })
→ String
Creates a path for a Dart file.
createProjectFile (String className , {Pattern prefix = "" })
→ TaycanProjectFile
Finds the class name from a className from a String
and returns a TaycanProjectFile object with the name and the path.
createTaycanProjectFile (String className , {Pattern prefix = "" })
→ TaycanProjectFile
Finds the class name from a className from a String
and returns a MetroProjectFile object.
hasHelpFlag (bool hasHelpFlag , String usage )
→ dynamic
loadAsset (String assetPath )
→ Future <String >
makeDirectory (String folderPath )
→ dynamic
Creates a new Page.
makePage (String className , String value , {String folderPath = pagesFolder , bool forceCreate = false , bool addToRoute = true , bool isInitialPage = false , bool isAuthPage = false , String ? creationPath })
→ dynamic
Creates a new Page.
runCommand (List <String > arguments , {required List <TcCommand ? > allCommands , required String menu })
→ Future <void >
Runs a command with the given arguments and allCommands.
The menu is the text that will be written to the console.
The allCommands is the list of all commands that can be given with Taycan.